@media all {
    .aa-srp .aasrp-form-field-errors {
        margin-top: 0.5rem;
    }

    .aa-srp form label {
        font-weight: normal;
    }

    .aa-srp form label .form-field-required {
        font-weight: bold;
    }
}
